@@ -26,6 +26,7 @@ class PrintSitePlugin(BasePlugin):
         ("add_table_of_contents", config_options.Type(bool, default=True)),
         ("add_full_urls", config_options.Type(bool, default=False)),
         ("enumerate_headings", config_options.Type(bool, default=False)),
+        ("enumerate_figures", config_options.Type(bool, default=False)),
     )
 
     def on_config(self, config, **kwargs):
@@ -85,6 +86,7 @@ class PrintSitePlugin(BasePlugin):
             insert_explain_block=True,
             insert_full_urls=self.config.get("add_full_urls"),
             insert_enumeration=self.config.get("enumerate_headings"),
+            insert_enumeration_figures=self.config.get("enumerate_figures"),
         )
 
         return config
@@ -116,6 +118,10 @@ class PrintSitePlugin(BasePlugin):
         # And apply it to the print page as well (in on_post_build event)
         self.context = context
 
+        # Save relative link to print page
+        # This can be used to customize a theme and add a print button to each page
+        page.url_to_print_page = self.print_file.url_relative_to(page.file)
+
     def on_post_build(self, config):
 
         # Add javascript file
